@@ -1,14 +1,26 @@
 from devsecops_engine_tools.engine_utilities.utils.api_error import ApiError
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
-from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.import_scan import ImportScanRestConsumer
-from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.product_type import ProductTypeRestConsumer
-from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.product import ProductRestConsumer
+from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.import_scan import (
+    ImportScanRestConsumer,
+)
+from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.product_type import (
+    ProductTypeRestConsumer,
+)
+from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.product import (
+    ProductRestConsumer,
+)
 from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.scan_configurations import (
     ScanConfigrationRestConsumer,
 )
-from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.engagement import EngagementRestConsumer
-from devsecops_engine_tools.engine_utilities.defect_dojo.domain.request_objects.import_scan import ImportScanRequest
-from devsecops_engine_tools.engine_utilities.defect_dojo.domain.user_case.import_scan import ImportScanUserCase
+from devsecops_engine_tools.engine_utilities.defect_dojo.infraestructure.driver_adapters.engagement import (
+    EngagementRestConsumer,
+)
+from devsecops_engine_tools.engine_utilities.defect_dojo.domain.request_objects.import_scan import (
+    ImportScanRequest,
+)
+from devsecops_engine_tools.engine_utilities.defect_dojo.domain.user_case.import_scan import (
+    ImportScanUserCase,
+)
 from devsecops_engine_tools.engine_utilities.utils.session_manager import SessionManager
 from devsecops_engine_tools.engine_utilities.settings import SETTING_LOGGER
 
@@ -22,11 +34,20 @@ class DefectDojo:
             if not isinstance(request, ImportScanRequest):
                 return request
             rest_import_scan = ImportScanRestConsumer(request, session=SessionManager())
-            rest_product_type = ProductTypeRestConsumer(request, session=SessionManager())
-            rest_product = ProductRestConsumer(request, session=SessionManager())
+            rest_product_type = ProductTypeRestConsumer(
+                request, session=SessionManager()
+            )
+            rest_product = ProductRestConsumer(
+                SessionManager(
+                    request.token_defect_dojo,
+                    request.host_defect_dojo,
+                )
+            )
             rest_engagement = EngagementRestConsumer(request, session=SessionManager())
 
-            rest_scan_configuration = ScanConfigrationRestConsumer(request, session=SessionManager())
+            rest_scan_configuration = ScanConfigrationRestConsumer(
+                request, session=SessionManager()
+            )
             uc = ImportScanUserCase(
                 rest_import_scan,
                 rest_product_type,
